==========================
Ninja Python Distributions
==========================

`Ninja <http://www.ninja-build.org>`_ is a small build system with a focus on speed.

The latest Ninja python wheels provide `ninja 1.10.2.g51db2.kitware.jobserver-1 <https://ninja-build.org/manual.html>`_ executable
and `ninja_syntax.py` for generating `.ninja` files.

.. image:: https://raw.githubusercontent.com/scikit-build/ninja-python-distributions/master/ninja-python-distributions-logo.png

Latest Release
--------------

.. table::

  +----------------------------------------------------------------------+---------------------------------------------------------------------------+
  | Versions                                                             | Downloads                                                                 |
  +======================================================================+===========================================================================+
  | .. image:: https://img.shields.io/pypi/v/ninja.svg                   | .. image:: https://img.shields.io/badge/downloads-2535k%20total-green.svg |
  |     :target: https://pypi.python.org/pypi/ninja                      |     :target: https://pypi.python.org/pypi/ninja                           |
  +----------------------------------------------------------------------+---------------------------------------------------------------------------+

Build Status
------------

.. table::

  +---------------+-------------------------------------------------------------------------------------------------------------+
  |               | GitHub Actions (Windows, macOS, Linux)                                                                      |
  +===============+=============================================================================================================+
  | PyPI          | .. image:: https://github.com/scikit-build/ninja-python-distributions/actions/workflows/build.yml/badge.svg |
  |               |     :target: https://github.com/scikit-build/ninja-python-distributions/actions/workflows/build.yml         |
  +---------------+-------------------------------------------------------------------------------------------------------------+

Maintainers
-----------

* `How to update ninja version ? <https://github.com/scikit-build/ninja-python-distributions/blob/master/docs/update_ninja_version.rst>`_

* `How to make a release ? <https://github.com/scikit-build/ninja-python-distributions/blob/master/docs/make_a_release.rst>`_


Miscellaneous
-------------

* Documentation: https://github.com/scikit-build/ninja-python-distributions#readme
* Source code: https://github.com/scikit-build/ninja-python-distributions
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build

License
-------

This project is maintained by Jean-Christophe Fillion-Robin from Kitware Inc.
It is covered by the `Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.

Ninja is also distributed under the `Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.
For more information about Ninja, visit https://ninja-build.org

Logo was originally created by Libby Rose from Kitware Inc.
It is covered by `CC BY 4.0 <https://creativecommons.org/licenses/by/4.0/>`_.
